@@ -336,8 +336,6 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
             raise ConnectionException(correlation_id, "CONNECT_FAILED", "PostgreSQL connection is not opened")
 
         self._client = self._connection.get_connection()
-        # add query method
-        self._request = self._request
 
         self._database_name = self._connection.get_database_name()
 
